import { memo, useEffect, useState } from "react";
import IcBaselineDeleteForever from "../icons/IcBaselineDeleteForever";
import api from "@/lib/api";
import { toast } from "react-toastify";
import { intervalToDuration, format } from 'date-fns';

interface Job {
	id: string
	cid: string
	customer_name: string
	bags: number[]
	stopwatch: number
	created_at: string
}

export default memo(function CompletedJobs(){
	const [jobs, setJobs] = useState<Job[]>([]);

	async function getJobs(){
		const {data}: {data: Job[]} = await api.get('/admin/jobs');
		setJobs(data);
	}

	async function deleteJob(id: string){
		await api.delete(`/admin/jobs/${id}`)
		toast.info('Job has been removed');
		await getJobs();
	}

	function timer(stopwatch: number): string{
		const i2d = intervalToDuration({start: 0, end: stopwatch*1000});
		return `${i2d.hours}h ${i2d.minutes}m ${i2d.seconds}s`;
	}

	useEffect(()=>{getJobs()}, []);

	return <>
		<div className="overflow-x-auto">
			<table className="table">
				<thead>
					<tr>
						<th>No.</th>
						<th>Customer name</th>
						<th>Bags weight</th>
						<th>Stopwatch</th>
						<th>Created at</th>
						<th>Actions</th>
					</tr>
				</thead>
				<tbody>
					{
						jobs.map((job, key)=>(
							<tr key={key}>
								<td>{key+1}</td>
								<td>{job.customer_name}</td>
								<td>
									<div className="flex flex-wrap gap-1">
										{job.bags.map((v, k)=>(<p key={k} className="badge badge-primary whitespace-nowrap">Bag {k+1}: {v} lb</p>))}
									</div>
									<p className="whitespace-nowrap">Total weight: {Number(job.bags.reduce((a: number, v)=>v ? Number(v)+a : a, 0).toFixed(2))} lb</p>
								</td>
								<td className="whitespace-nowrap">{timer(job.stopwatch)}</td>
								<td>
									<p className="whitespace-nowrap">{format(new Date(job.created_at), 'yyyy-M-d')}</p>
									<p className="whitespace-nowrap">{format(new Date(job.created_at), 'h:m:s aaa')}</p>
								</td>
								<td>
									<div className="flex gap-x-2">
										<button onClick={()=>{deleteJob(job.id)}} className="btn btn-sm btn-square btn-error border-none btn-outline fill-error hover:fill-white">
											<div className="w-6 h-6"><IcBaselineDeleteForever /></div>
										</button>
									</div>
								</td>
							</tr>
						))
					}
				</tbody>
			</table>
		</div>
	</>
})
